==> haskell-vty-crossplatform-0.4.0.0-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-Khy1RoWjba7Qork7VqcCx
key:                  vty-crossplatform-0.4.0.0-Khy1RoWjba7Qork7VqcCx
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  cfa5890a0783965940b5eaac16f1c373
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-Khy1RoWjba7Qork7VqcCx
depends:
    base-4.18.2.1 vty-6.2-GJSVM62QIvN9hRMOjtPpjh
    vty-unix-0.2.0.0-K1qySh95uTQukeSSo5X15

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-crossplatform-0.4.0.0-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-JXeczINCqpc7njmMYOsM3T
key:                  vty-crossplatform-0.4.0.0-JXeczINCqpc7njmMYOsM3T
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  65aae3ba46399ca8934d95b56f28b140
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-JXeczINCqpc7njmMYOsM3T
depends:
    base-4.18.2.1 vty-6.2-INuzoHGEuLa5SMM40Z8Lln
    vty-unix-0.2.0.0-IK7ktvVFKgPJ14dHq2TOab

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
